documentFactory.HttpDocumentStream

|  | ## Cheshire3 Object Model: Class HttpDocumentStream

Module documentFactory :: Class HttpDocumentStream

## Class HttpDocumentStream
source code

Object Tree:

    BaseDocumentStream --+
                         |
    MultipleDocumentStream --+
                             |
                            HttpDocumentStream

Known Subclasses:
  GoogleDocumentStream, OaiDocumentStream, OpensearchDocumentStream, SruDocumentStream, SrwDocumentStream, SyndicationDocumentStream

Instance Methods

__init__(self, session, stream, format, schema=None, codec=None, factory=None)
_processFile(self, session, item)
find_documents(self, session, cache=0)
_fetchName(self, item)
_fetchStream(self, url)
Inherited from `MultipleDocumentStream` (private): `_processFiles` Inherited from `BaseDocumentStream`: `fetch_document`, `open_stream`

Class Variables

Inherited from `BaseDocumentStream`: `codec`, `documents`, `factory`, `filterRe`, `format`, `length`, `locations`, `schema`, `stream`, `streamLocation`

Method Details

### __init__(self, session, stream, format, schema=None, codec=None, factory=None) (Constructor) | source code
Overrides: MultipleDocumentStream.__init__

### _processFile(self, session, item) | source code
Overrides: MultipleDocumentStream._processFile

### find_documents(self, session, cache=0) | source code

### _fetchName(self, item) | source code
Overrides: MultipleDocumentStream._fetchName

### _fetchStream(self, url) | source code
Overrides: MultipleDocumentStream._fetchStream